package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.MobileNotify;

/**
 * 语音通知号码Service接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface IMobileNotifyService 
{
    /**
     * 查询语音通知号码
     * 
     * @param id 语音通知号码主键
     * @return 语音通知号码
     */
    public MobileNotify selectMobileNotifyById(Long id);

    /**
     * 查询语音通知号码列表
     * 
     * @param mobileNotify 语音通知号码
     * @return 语音通知号码集合
     */
    public List<MobileNotify> selectMobileNotifyList(MobileNotify mobileNotify);

    /**
     * 新增语音通知号码
     * 
     * @param mobileNotify 语音通知号码
     * @return 结果
     */
    public int insertMobileNotify(MobileNotify mobileNotify);

    /**
     * 修改语音通知号码
     * 
     * @param mobileNotify 语音通知号码
     * @return 结果
     */
    public int updateMobileNotify(MobileNotify mobileNotify);

    /**
     * 批量删除语音通知号码
     * 
     * @param ids 需要删除的语音通知号码主键集合
     * @return 结果
     */
    public int deleteMobileNotifyByIds(Long[] ids);

    /**
     * 删除语音通知号码信息
     * 
     * @param id 语音通知号码主键
     * @return 结果
     */
    public int deleteMobileNotifyById(Long id);
}
